#include <msp430g2152.h>

int pc = 0;
int n = 0;

void time_1ms(int dlms)
{
	while (dlms--)
	{
		__delay_cycles(1000);
	}
}

void program(int lights, int steps, int dl, int bs, int kk)
{
	int i = 0;
	int j = 0;
	int k = 0;

	for (j = 0; j < steps; j++)
	{
		for (k = 0; k < kk; k++)
		{
			for (i = 0; i < lights; i++)	// total 0.5s -1s
			{
				if (i == 0 && j == 0)
				{
					P1OUT = 0x01;
					time_1ms(dl);
				}
				else if (i == 0)
				{
					P1OUT = 0x01 << j;
					time_1ms(dl);
				}
				else
				{
					P1OUT = P1OUT << bs;
					time_1ms(dl);
				}
			}
		}						// time < 0.5s - 1s (timer)
	}
}


#pragma vector = PORT2_VECTOR
__interrupt void Port_2(void)
{
	if (pc > 3)					// program + 1
	{
		pc = 1;
	}
	else
	{
		pc = pc+1;
	}
	P2IFG &= ~0x01;      		// P2.0 IFG cleared
}

void main(void)
{
	WDTCTL = WDTPW + WDTHOLD;

	if (CALBC1_1MHZ == 0xFF || CALDCO_1MHZ == 0xFF)
	{
		while(1);
	}

	BCSCTL1 = CALBC1_1MHZ;		// else dco-default ~800kHz
	DCOCTL = CALDCO_1MHZ;

	P1SEL = 0;					// P1.x I/O
	P1DIR = 0xff;				// P1.x output
	P1OUT = 0x00;

	P2SEL = 0;					// P2.x I/O
	P2DIR = 0xfe;				// P2.0 input, else output
	P2OUT = 0x00;

	P2IES |= 0x01;				// P2.0 high/low
	P2IFG &= ~0x01;				// P2.0 IFG clear
	P2IE |= 0x01;				// P2.0 int enabled

	_EINT();

	while(1)
	{
		switch(pc)							// change it again for the push button
		{
			case 1: program(1,8,2,1,25);		// 1 light running, 25, k < 30
			break;
			case 2: program(2,4,2,4,25);		// 2 lights, looks ok, but slow with k < 20 and dl = 3
			break;
			case 3: program(4,2,2,2,25);		// 4 lights, timing ok, lights ok, program ok, with k < 50, maybe a bit less, later program 3
			break;
			case 4: program(8,1,1,1,1);		// 8 lights on, numbers are ok
			break;
			default: P1OUT = 0x00;
		}
	}
}
